@@ -198,16 +198,19 @@ class Crawler(Controller):
             plugin_names.append(input_plugin_name)
 
         for plugin_name in plugin_names:
-            print(f'Initiating Deplyment: {plugin_name} ')
+            print(f'Initiating Deplyment for: {plugin_name} ')
 
             plugin_name = plugin_name.strip()
 
             plugin_dir_path = get_plugin_path(plugin_name, all_types=True)
 
             if(plugin_dir_path):
-                system(
-                    f"""cd {plugin_dir_path} && cd .. && git pull origin master""")
-
+                # system(f"""
+                # cd {plugin_dir_path} && 
+                # cd .. &&
+                # git pull 
+                # """)
+          
                 plugin_info = get_plugin_info(plugin_dir_path)
                 version_path = '{}/.version'.format(plugin_dir_path)
                 if(path.exists(version_path)):
@@ -247,9 +250,13 @@ class Crawler(Controller):
                 cd .. &&
                 git add {}/ &&
                 git commit -m "[{}] [{}] {}" &&
-                git push origin master
+                git pull && 
+                git push
                 """.format(plugin_dir_path, plugin_name, deploy_type, version_info, deploy_message)
 
+                # sleep for 2 second to make it look real deployment
+                time.sleep(2)
+
                 show_schema(plugin_dir_path)
 
                 system(command)
